#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-files-dock-widget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/moc-files-dock-widget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-files-dock-widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__files_dock_widget_t {
    QByteArrayData data[61];
    char stringdata0[1065];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__files_dock_widget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__files_dock_widget_t qt_meta_stringdata_octave__files_dock_widget = {
    {
QT_MOC_LITERAL(0, 0, 25), // "octave::files_dock_widget"
QT_MOC_LITERAL(1, 26, 9), // "open_file"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 8), // "fileName"
QT_MOC_LITERAL(4, 46, 27), // "displayed_directory_changed"
QT_MOC_LITERAL(5, 74, 3), // "dir"
QT_MOC_LITERAL(6, 78, 16), // "load_file_signal"
QT_MOC_LITERAL(7, 95, 15), // "open_any_signal"
QT_MOC_LITERAL(8, 111, 15), // "run_file_signal"
QT_MOC_LITERAL(9, 127, 9), // "QFileInfo"
QT_MOC_LITERAL(10, 137, 4), // "info"
QT_MOC_LITERAL(11, 142, 17), // "find_files_signal"
QT_MOC_LITERAL(12, 160, 8), // "startdir"
QT_MOC_LITERAL(13, 169, 18), // "file_remove_signal"
QT_MOC_LITERAL(14, 188, 8), // "old_name"
QT_MOC_LITERAL(15, 197, 8), // "new_name"
QT_MOC_LITERAL(16, 206, 19), // "file_renamed_signal"
QT_MOC_LITERAL(17, 226, 18), // "modify_path_signal"
QT_MOC_LITERAL(18, 245, 8), // "dir_list"
QT_MOC_LITERAL(19, 254, 2), // "rm"
QT_MOC_LITERAL(20, 257, 7), // "subdirs"
QT_MOC_LITERAL(21, 265, 19), // "item_double_clicked"
QT_MOC_LITERAL(22, 285, 5), // "index"
QT_MOC_LITERAL(23, 291, 19), // "change_directory_up"
QT_MOC_LITERAL(24, 311, 24), // "do_sync_octave_directory"
QT_MOC_LITERAL(25, 336, 25), // "do_sync_browser_directory"
QT_MOC_LITERAL(26, 362, 21), // "set_current_directory"
QT_MOC_LITERAL(27, 384, 26), // "accept_directory_line_edit"
QT_MOC_LITERAL(28, 411, 23), // "update_octave_directory"
QT_MOC_LITERAL(29, 435, 15), // "notice_settings"
QT_MOC_LITERAL(30, 451, 13), // "save_settings"
QT_MOC_LITERAL(31, 465, 20), // "restore_header_state"
QT_MOC_LITERAL(32, 486, 27), // "headercontextmenu_requested"
QT_MOC_LITERAL(33, 514, 3), // "pos"
QT_MOC_LITERAL(34, 518, 13), // "toggle_header"
QT_MOC_LITERAL(35, 532, 3), // "col"
QT_MOC_LITERAL(36, 536, 21), // "contextmenu_requested"
QT_MOC_LITERAL(37, 558, 16), // "contextmenu_open"
QT_MOC_LITERAL(38, 575, 26), // "contextmenu_open_in_editor"
QT_MOC_LITERAL(39, 602, 23), // "contextmenu_open_in_app"
QT_MOC_LITERAL(40, 626, 26), // "contextmenu_copy_selection"
QT_MOC_LITERAL(41, 653, 15), // "contextmenu_run"
QT_MOC_LITERAL(42, 669, 16), // "contextmenu_load"
QT_MOC_LITERAL(43, 686, 18), // "contextmenu_rename"
QT_MOC_LITERAL(44, 705, 18), // "contextmenu_delete"
QT_MOC_LITERAL(45, 724, 19), // "contextmenu_newfile"
QT_MOC_LITERAL(46, 744, 18), // "contextmenu_newdir"
QT_MOC_LITERAL(47, 763, 25), // "contextmenu_setcurrentdir"
QT_MOC_LITERAL(48, 789, 23), // "contextmenu_add_to_path"
QT_MOC_LITERAL(49, 813, 31), // "contextmenu_add_to_path_subdirs"
QT_MOC_LITERAL(50, 845, 24), // "contextmenu_rm_from_path"
QT_MOC_LITERAL(51, 870, 32), // "contextmenu_rm_from_path_subdirs"
QT_MOC_LITERAL(52, 903, 21), // "contextmenu_findfiles"
QT_MOC_LITERAL(53, 925, 19), // "popdownmenu_newfile"
QT_MOC_LITERAL(54, 945, 18), // "popdownmenu_newdir"
QT_MOC_LITERAL(55, 964, 22), // "popdownmenu_search_dir"
QT_MOC_LITERAL(56, 987, 21), // "popdownmenu_findfiles"
QT_MOC_LITERAL(57, 1009, 16), // "popdownmenu_home"
QT_MOC_LITERAL(58, 1026, 13), // "copyClipboard"
QT_MOC_LITERAL(59, 1040, 14), // "pasteClipboard"
QT_MOC_LITERAL(60, 1055, 9) // "selectAll"

    },
    "octave::files_dock_widget\0open_file\0"
    "\0fileName\0displayed_directory_changed\0"
    "dir\0load_file_signal\0open_any_signal\0"
    "run_file_signal\0QFileInfo\0info\0"
    "find_files_signal\0startdir\0"
    "file_remove_signal\0old_name\0new_name\0"
    "file_renamed_signal\0modify_path_signal\0"
    "dir_list\0rm\0subdirs\0item_double_clicked\0"
    "index\0change_directory_up\0"
    "do_sync_octave_directory\0"
    "do_sync_browser_directory\0"
    "set_current_directory\0accept_directory_line_edit\0"
    "update_octave_directory\0notice_settings\0"
    "save_settings\0restore_header_state\0"
    "headercontextmenu_requested\0pos\0"
    "toggle_header\0col\0contextmenu_requested\0"
    "contextmenu_open\0contextmenu_open_in_editor\0"
    "contextmenu_open_in_app\0"
    "contextmenu_copy_selection\0contextmenu_run\0"
    "contextmenu_load\0contextmenu_rename\0"
    "contextmenu_delete\0contextmenu_newfile\0"
    "contextmenu_newdir\0contextmenu_setcurrentdir\0"
    "contextmenu_add_to_path\0"
    "contextmenu_add_to_path_subdirs\0"
    "contextmenu_rm_from_path\0"
    "contextmenu_rm_from_path_subdirs\0"
    "contextmenu_findfiles\0popdownmenu_newfile\0"
    "popdownmenu_newdir\0popdownmenu_search_dir\0"
    "popdownmenu_findfiles\0popdownmenu_home\0"
    "copyClipboard\0pasteClipboard\0selectAll"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__files_dock_widget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      48,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  254,    2, 0x06 /* Public */,
       4,    1,  257,    2, 0x06 /* Public */,
       6,    1,  260,    2, 0x06 /* Public */,
       7,    1,  263,    2, 0x06 /* Public */,
       8,    1,  266,    2, 0x06 /* Public */,
      11,    1,  269,    2, 0x06 /* Public */,
      13,    2,  272,    2, 0x06 /* Public */,
      16,    1,  277,    2, 0x06 /* Public */,
      17,    3,  280,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      21,    1,  287,    2, 0x0a /* Public */,
      23,    0,  290,    2, 0x0a /* Public */,
      24,    0,  291,    2, 0x0a /* Public */,
      25,    0,  292,    2, 0x0a /* Public */,
      26,    1,  293,    2, 0x0a /* Public */,
      27,    0,  296,    2, 0x0a /* Public */,
      28,    1,  297,    2, 0x0a /* Public */,
      29,    0,  300,    2, 0x0a /* Public */,
      30,    0,  301,    2, 0x0a /* Public */,
      31,    0,  302,    2, 0x08 /* Private */,
      32,    1,  303,    2, 0x08 /* Private */,
      34,    1,  306,    2, 0x08 /* Private */,
      36,    1,  309,    2, 0x08 /* Private */,
      37,    1,  312,    2, 0x08 /* Private */,
      38,    1,  315,    2, 0x08 /* Private */,
      39,    1,  318,    2, 0x08 /* Private */,
      40,    1,  321,    2, 0x08 /* Private */,
      41,    1,  324,    2, 0x08 /* Private */,
      42,    1,  327,    2, 0x08 /* Private */,
      43,    1,  330,    2, 0x08 /* Private */,
      44,    1,  333,    2, 0x08 /* Private */,
      45,    1,  336,    2, 0x08 /* Private */,
      46,    1,  339,    2, 0x08 /* Private */,
      47,    1,  342,    2, 0x08 /* Private */,
      48,    3,  345,    2, 0x08 /* Private */,
      48,    2,  352,    2, 0x28 /* Private | MethodCloned */,
      48,    1,  357,    2, 0x28 /* Private | MethodCloned */,
      49,    1,  360,    2, 0x08 /* Private */,
      50,    1,  363,    2, 0x08 /* Private */,
      51,    1,  366,    2, 0x08 /* Private */,
      52,    1,  369,    2, 0x08 /* Private */,
      53,    1,  372,    2, 0x08 /* Private */,
      54,    1,  375,    2, 0x08 /* Private */,
      55,    1,  378,    2, 0x08 /* Private */,
      56,    1,  381,    2, 0x08 /* Private */,
      57,    1,  384,    2, 0x08 /* Private */,
      58,    0,  387,    2, 0x08 /* Private */,
      59,    0,  388,    2, 0x08 /* Private */,
      60,    0,  389,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   14,   15,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QStringList, QMetaType::Bool, QMetaType::Bool,   18,   19,   20,

 // slots: parameters
    QMetaType::Void, QMetaType::QModelIndex,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   33,
    QMetaType::Void, QMetaType::Int,   35,
    QMetaType::Void, QMetaType::QPoint,   33,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool,    2,   19,   20,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,    2,   19,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        files_dock_widget *_t = static_cast<files_dock_widget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->open_file((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->displayed_directory_changed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->load_file_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->open_any_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->run_file_signal((*reinterpret_cast< const QFileInfo(*)>(_a[1]))); break;
        case 5: _t->find_files_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->file_remove_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 7: _t->file_renamed_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->modify_path_signal((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 9: _t->item_double_clicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 10: _t->change_directory_up(); break;
        case 11: _t->do_sync_octave_directory(); break;
        case 12: _t->do_sync_browser_directory(); break;
        case 13: _t->set_current_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->accept_directory_line_edit(); break;
        case 15: _t->update_octave_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->notice_settings(); break;
        case 17: _t->save_settings(); break;
        case 18: _t->restore_header_state(); break;
        case 19: _t->headercontextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 20: _t->toggle_header((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->contextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 22: _t->contextmenu_open((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->contextmenu_open_in_editor((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->contextmenu_open_in_app((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->contextmenu_copy_selection((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: _t->contextmenu_load((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->contextmenu_rename((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->contextmenu_delete((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 30: _t->contextmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 31: _t->contextmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->contextmenu_setcurrentdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 33: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 34: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 35: _t->contextmenu_add_to_path((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 36: _t->contextmenu_add_to_path_subdirs((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 37: _t->contextmenu_rm_from_path((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 38: _t->contextmenu_rm_from_path_subdirs((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 39: _t->contextmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 40: _t->popdownmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 41: _t->popdownmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 42: _t->popdownmenu_search_dir((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 43: _t->popdownmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 44: _t->popdownmenu_home((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 45: _t->copyClipboard(); break;
        case 46: _t->pasteClipboard(); break;
        case 47: _t->selectAll(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (files_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::open_file)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (files_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::displayed_directory_changed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (files_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::load_file_signal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (files_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::open_any_signal)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (files_dock_widget::*_t)(const QFileInfo & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::run_file_signal)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (files_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::find_files_signal)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (files_dock_widget::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::file_remove_signal)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (files_dock_widget::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::file_renamed_signal)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (files_dock_widget::*_t)(const QStringList & , bool , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::modify_path_signal)) {
                *result = 8;
                return;
            }
        }
    }
}

const QMetaObject octave::files_dock_widget::staticMetaObject = {
    { &octave_dock_widget::staticMetaObject, qt_meta_stringdata_octave__files_dock_widget.data,
      qt_meta_data_octave__files_dock_widget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::files_dock_widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::files_dock_widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__files_dock_widget.stringdata0))
        return static_cast<void*>(this);
    return octave_dock_widget::qt_metacast(_clname);
}

int octave::files_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = octave_dock_widget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 48;
    }
    return _id;
}

// SIGNAL 0
void octave::files_dock_widget::open_file(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void octave::files_dock_widget::displayed_directory_changed(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void octave::files_dock_widget::load_file_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void octave::files_dock_widget::open_any_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void octave::files_dock_widget::run_file_signal(const QFileInfo & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void octave::files_dock_widget::find_files_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void octave::files_dock_widget::file_remove_signal(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void octave::files_dock_widget::file_renamed_signal(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void octave::files_dock_widget::modify_path_signal(const QStringList & _t1, bool _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
